==> 2024-09-23_11-02-21.zip: opt/retropie/configs/all/autostart.sh <==
sys_dir='/home/pi/ADMIN/.sys'
data_dir='/home/pi/CAFCA/data'


[ -f /boot/boot.sh ] && sudo cp -f /boot/boot.sh /tmp/boot.sh
[ -f /boot/sys_settings ] && sudo cp -f /boot/sys_settings "$sys_dir/.settings"
[ -f /boot/sys_states ]   && sudo cp -f /boot/sys_states   "$sys_dir/.states"

roms_path=$(grep -w -m1 'dir_roms' "$sys_dir/.settings"  | cut -d\' -f2)
boot_mode=$(grep -w boot_mode "$sys_dir/.settings" | cut -d\' -f2)

[[ $(grep -Pc '\x0d' /tmp/boot.sh) -gt 0 ]] && sudo sed -i 's/\r//g' /tmp/boot.sh; sudo chmod 775 "$sys_dir/.settings" "$sys_dir/.states" "/tmp/boot.sh"

sudo bash /tmp/boot.sh &

while [[ $(grep BOOTED "$sys_dir/.states" | cut -d= -f2) -lt 1 ]]; do :; done; clear

[[ $boot_mode != es ]] && sleep 10

if [[ $boot_mode == es ]]; then
  sudo bash /home/pi/ADMIN/CMD/PLAY/INTRO.sh 2 &
  emulationstation --no-splash --debug >/dev/null > >(sudo tee -a /home/pi/ADMIN/.log/emulationstation.log) 2>&1
elif [[ $boot_mode == menu ]]; then
  dialog --create-rc /home/pi/.dialogrc
  cp -f /home/pi/ADMIN/MENU/.assets/config/.dialogrc /home/pi/.dialogrc
  #sudo chown pi:root /home/pi/.dialogrc; sudo chmod +x /home/pi/.dialogrc

  # REM
  #echo "VFD 2 DIALOG" > /tmp/serial.fifo
  #dialog --create-rc /home/pi/.dialogrc; sudo chown pi:root /home/pi/.dialogrc; sudo chmod +x /home/pi/.dialogrc
  #cp -f /home/pi/ADMIN/MENU/.assets/config/.dialogrc /home/pi/.dialogrc
  #dialog --colors --title "MENU" --yesno "ITEM" 20 40
  #rm /home/pi/.dialogrc
  #clear
  # REM

  sudo bash /home/pi/ADMIN/MENU/MENU.sh BOOT
fi




# ----------------------------------------------------------------------------------
#
#boot_modes=( 'none' 'term' 'es' 'menu' 'game' )
#
#if [[ ${boot_modes[@]} =~ $boot_mode ]]; then
#  [[ $boot_mode != es ]] && sleep 10
#
#  case $boot_mode in
#    'term')
#      sudo bash /home/pi/ADMIN/.sys/thd/states.sh --mode menu; sudo bash /home/pi/ADMIN/.sys/thd/states.sh --grab joystick
#      sudo setterm --cursor on
#      ;;
#
#    'es')
#      sudo bash /home/pi/ADMIN/CMD/PLAY/INTRO.sh 2 &
#      emulationstation --no-splash --debug >/dev/null > >(sudo tee -a /home/pi/ADMIN/.log/emulationstation.log) 2>&1
#      ;;
#
#    'menu'|'game')
#      start_game=$(grep -w -m1 'game_on_boot' "$sys_dir/.settings" | cut -d\' -f2)
#
#      if [[ ${#start_game} -gt 0 ]]; then
#        system="${start_game%%/*}"; game="${start_game##*/}"
#        ext=$(grep -w -A3 "<name>${system}</name>" /home/pi/.emulationstation/es_systems.cfg | grep -w -m1 '<extension>' | cut -d. -f2)
#        path="${roms_path}/${system}/${game}.${ext}"
#
#        sudo sed -i "s|ACTIVE_GAME[=].*$|ACTIVE_GAME=\x27${system}\/${game}\x27|g" "$data_dir/.settings"
#        sudo bash "$sys_dir/thd/states.sh" --mode game; sudo bash "$sys_dir/thd/states.sh" --remove joystick
#        sudo -u pi bash -c "python3 /opt/retropie/configs/all/CRT/bin/GeneralModule/emulator_launcher.py ${path} ${system} dummy"
#        sudo bash "$sys_dir/thd/states.sh" --mode menu; sudo bash "$sys_dir/thd/states.sh" --grab joystick
#      fi
#
#      if [[ $boot_mode == menu ]]; then
#        sudo bash /home/pi/ADMIN/CMD/PLAY/INTRO.sh >/dev/null 2>&1 & sleep 2
#        sudo bash /home/pi/ADMIN/MENU/GAMES/GAMES.sh "BOOT"
#        [ $? -eq 42 ] && sudo bash /home/pi/ADMIN/MENU/MAIN.sh
#
#        #if [ $? -eq 42 ]; then
#        #  while true; do
#        #    sudo bash /home/pi/ADMIN/MENU/MAIN.sh
#        #    [ $? -eq 42 ] && sudo bash /home/pi/ADMIN/MENU/GAMES/GAMES.sh
#        #  done
#        #fi
#      fi
#      ;;
#    *)
#      ;;
#  esac
#fi

==> 2024-09-24_17-31-50.zip: opt/retropie/configs/all/autostart.sh <==
sys_dir='/home/pi/ADMIN/.sys'
data_dir='/home/pi/CAFCA/data'


[ -f /boot/boot.sh ] && sudo cp -f /boot/boot.sh /tmp/boot.sh
[ -f /boot/sys_settings ] && sudo cp -f /boot/sys_settings "$sys_dir/.settings"
[ -f /boot/sys_states ]   && sudo cp -f /boot/sys_states   "$sys_dir/.states"

roms_path=$(grep -w -m1 'dir_roms' "$sys_dir/.settings"  | cut -d\' -f2)
boot_mode=$(grep -w boot_mode "$sys_dir/.settings" | cut -d\' -f2)

[[ $(grep -Pc '\x0d' /tmp/boot.sh) -gt 0 ]] && sudo sed -i 's/\r//g' /tmp/boot.sh; sudo chmod 775 "$sys_dir/.settings" "$sys_dir/.states" "/tmp/boot.sh"

sudo bash /tmp/boot.sh &

while [[ $(grep BOOTED "$sys_dir/.states" | cut -d= -f2) -lt 1 ]]; do :; done; clear

[[ $boot_mode != es ]] && sleep 10

if [[ $boot_mode == es ]]; then
  sudo bash /home/pi/ADMIN/CMD/PLAY/INTRO.sh 2 &
  emulationstation --no-splash --debug >/dev/null > >(sudo tee -a /home/pi/ADMIN/.log/emulationstation.log) 2>&1
elif [[ $boot_mode == menu ]]; then
  #dialog --create-rc /home/pi/.dialogrc
  #cp -f /home/pi/ADMIN/MENU/.assets/config/.dialogrc /home/pi/.dialogrc

  sudo bash /home/pi/ADMIN/MENU/MENU.sh BOOT
fi




# ----------------------------------------------------------------------------------
#
#boot_modes=( 'none' 'term' 'es' 'menu' 'game' )
#
#if [[ ${boot_modes[@]} =~ $boot_mode ]]; then
#  [[ $boot_mode != es ]] && sleep 10
#
#  case $boot_mode in
#    'term')
#      sudo bash /home/pi/ADMIN/.sys/thd/states.sh --mode menu; sudo bash /home/pi/ADMIN/.sys/thd/states.sh --grab joystick
#      sudo setterm --cursor on
#      ;;
#
#    'es')
#      sudo bash /home/pi/ADMIN/CMD/PLAY/INTRO.sh 2 &
#      emulationstation --no-splash --debug >/dev/null > >(sudo tee -a /home/pi/ADMIN/.log/emulationstation.log) 2>&1
#      ;;
#
#    'menu'|'game')
#      start_game=$(grep -w -m1 'game_on_boot' "$sys_dir/.settings" | cut -d\' -f2)
#
#      if [[ ${#start_game} -gt 0 ]]; then
#        system="${start_game%%/*}"; game="${start_game##*/}"
#        ext=$(grep -w -A3 "<name>${system}</name>" /home/pi/.emulationstation/es_systems.cfg | grep -w -m1 '<extension>' | cut -d. -f2)
#        path="${roms_path}/${system}/${game}.${ext}"
#
#        sudo sed -i "s|ACTIVE_GAME[=].*$|ACTIVE_GAME=\x27${system}\/${game}\x27|g" "$data_dir/.settings"
#        sudo bash "$sys_dir/thd/states.sh" --mode game; sudo bash "$sys_dir/thd/states.sh" --remove joystick
#        sudo -u pi bash -c "python3 /opt/retropie/configs/all/CRT/bin/GeneralModule/emulator_launcher.py ${path} ${system} dummy"
#        sudo bash "$sys_dir/thd/states.sh" --mode menu; sudo bash "$sys_dir/thd/states.sh" --grab joystick
#      fi
#
#      if [[ $boot_mode == menu ]]; then
#        sudo bash /home/pi/ADMIN/CMD/PLAY/INTRO.sh >/dev/null 2>&1 & sleep 2
#        sudo bash /home/pi/ADMIN/MENU/GAMES/GAMES.sh "BOOT"
#        [ $? -eq 42 ] && sudo bash /home/pi/ADMIN/MENU/MAIN.sh
#
#        #if [ $? -eq 42 ]; then
#        #  while true; do
#        #    sudo bash /home/pi/ADMIN/MENU/MAIN.sh
#        #    [ $? -eq 42 ] && sudo bash /home/pi/ADMIN/MENU/GAMES/GAMES.sh
#        #  done
#        #fi
#      fi
#      ;;
#    *)
#      ;;
#  esac
#fi
